#version 330

/**
 * Note that we need no variables from the VBO (since we are
 * setting the position via uniform variables).
 *
 * Instead, we only use the build-in variable gl_VertexID which
 * is automatically provided by OpenGL and returns the vertex
 * index.
 */

/**
 * Start position of the line:
 */
uniform vec4 startPosition;

/**
 * End position of the line:
 */
uniform vec4 endPosition;

/**
 * Using a model matrix (this allows to view the line from different
 * sides in this exercise).
 */
uniform mat4 model;

/**
 * The main function of the vertex shader, which is executed
 * for every vertex.
 */
void main()
{
    // We use the variable gl_VertexID to determine whether we set the
    // position to the start or end position:
    if(gl_VertexID == 0)
        gl_Position = model * startPosition;
    else
        gl_Position = model * endPosition;
}
