#include "LineDrawer.h"

#include <iostream>

LineDrawer::LineDrawer()
    : shader(CMAKE_SOURCE_DIR "/shader/lineDrawer.vert", CMAKE_SOURCE_DIR "/shader/lineDrawer.frag")
{
    // Generate VAO:
    glGenVertexArrays(1, &vao);
    glBindVertexArray(vao);

    // Generate VBO:
    glGenBuffers(1, &vbo);
    glBindBuffer(GL_ARRAY_BUFFER, vbo);

    // Generate an empty buffer, which is not used as the
    // vertex positions are overwritten in the vertex shader
    // by uniform variables:
    float buffer[8] = {0};
    glBufferData(GL_ARRAY_BUFFER, sizeof(buffer), &buffer[0], GL_STATIC_DRAW);

    // Link the VBO to the VAO:
    glVertexAttribPointer(0, 4, GL_FLOAT, GL_FALSE, 0, 0);
    glEnableVertexAttribArray(0);

    // Unbind the buffers:
    glBindBuffer(GL_ARRAY_BUFFER, 0);
    glBindVertexArray(0);
}

LineDrawer::~LineDrawer(){
    // Assume that vao / vbo were generated in every case:
    glDeleteVertexArrays(1, &vao);
    glDeleteBuffers(1, &vbo);
}

void LineDrawer::draw(Vec4f startPosition, Vec4f endPosition, Vec4f color, Mat4f modelMatrix){
    shader.bind();
    // Forward the positions and colors to the shader:
    shader.setUniform("startPosition", startPosition);
    shader.setUniform("endPosition", endPosition);
    shader.setUniform("color", color);
    shader.setUniform("model", modelMatrix);

    // Finally draw the lines:
    glBindVertexArray(vao);
    glDrawArrays(GL_LINES, 0, 2);
}
